import type { NextPage } from "next";
import { signIn, signOut, useSession } from "next-auth/react";
import dynamic from "next/dynamic";
import Head from "next/head";
import { Suspense } from "react";

const DynamicHeader = dynamic(() => import("../components/Header"), {
  suspense: true,
});

const SignInOutButton = ({ isSignedIn }: { isSignedIn: boolean }) => {
  if (isSignedIn) {
    return <button onClick={() => signOut()}>Sign Out</button>;
  }
  return <button onClick={() => signIn()}>Sign in</button>;
};

const Home: NextPage = () => {
  const { data: session, status } = useSession();
  const authData = {
    session,
    status,
  };

  console.log(status);

  return (
    <>
      <Head>
        <title>Tube Archivist</title>
        <meta name="description" content="Generated by create next app" />
        <link rel="icon" href="/favicon/favicon.ico" />
      </Head>

      <Suspense fallback={<h1>Loading</h1>}>
        <DynamicHeader authData={authData} />
      </Suspense>

      <div
        style={{
          display: "flex",
          flexDirection: "column",
          maxWidth: "100px",
        }}
      >
        <SignInOutButton isSignedIn={!!session?.user} />
      </div>
    </>
  );
};

export default Home;
